@@ -1,11 +1,13 @@
 import requests
 import pprint
 from python_nbaclient import REQ_HEADER
-from python_nbaclient.constants import League, EndPoints
+from python_nbaclient.constants import EndPoints
+from python_nbaclient.constants import CURRENT_SEASON, LEAGUE_ID
 
+endpoints = EndPoints().endpoints
 
 class TeamList:
-    def __init__(self, league_id=League.league_id):
+    def __init__(self, league_id=league_id):
         """
         :param league_id String: id of the league
         """
@@ -16,12 +18,13 @@ class TeamDetails:
         """
         :param team_id integer: id of the team
         """
-        self._url = EndPoints.endpoints["TeamDetails"]
+        self._url = endpoints["TeamDetails"]
         self._api_param = {"teamID": team_id}
         self._headers = REQ_HEADER
         response = requests.get(self._url,
                                 headers=self._headers,
                                 params=self._api_param)
+
         if response.status_code == 200:
             self.team_details = response.json()
             pp = pprint.PrettyPrinter(indent=2)
@@ -37,14 +40,14 @@ class TeamDetails:
 
 class CommonTeamRoster:
     # ToDo: league_id: 00 means?, season: current year?
-    def __init__(self, team_id, season, league_id=League.league_id):
+    def __init__(self, team_id, season=CURRENT_SEASON, league_id=LEAGUE_ID):
         """
         :param team_id: id of the team
         :param season: NBA season, String, "2019-20"
         :param league_id: NBA league ID, String
         """
 
-        self._url = EndPoints.endpoints["CommonTeamRoster"]
+        self._url = endpoints["CommonTeamRoster"]
         self._api_param = {
             "TeamID": team_id,
             "LeagueID": league_id,
@@ -56,6 +59,7 @@ class CommonTeamRoster:
         response = requests.get(self._url,
                                 headers=self._headers,
                                 params=self._api_param)
+
         if response.status_code == 200:
             self.team_roster = response.json()
             pp = pprint.PrettyPrinter(indent=2)
@@ -73,13 +77,14 @@ class FranchiseLeaders:
         """
         :param team_id: id of the team
         """
-        self._url = EndPoints.endpoints["FranchiseLeaders"]
+        self._url = endpoints["FranchiseLeaders"]
         self._api_param = {"TeamID": team_id}
         self._headers = REQ_HEADER
 
         response = requests.get(self._url,
                                 headers=self._headers,
                                 params=self._api_param)
+
         if response.status_code == 200:
             self.franchise_leader = response.json()
             pp = pprint.PrettyPrinter(indent=2)
